Modules
- config
config - Module for ProSA configuration object
- hash
msgorqueue - Module for hashing helpers
- msg
msg - Module for ProSA internal messaging object
- queue
queue - Module for ProSA internal queueing utilitary
Macros
- id_
in_ queue queue - Macro of an expression to know if an id is still contain by the queue that have a circular buffer