Module queue

Module queue 

Available on crate feature queue only.
Module for ProSA internal queueing utilitary

Re-exports

pub use crate::hash::IsInteger;

Modules

mpsc
Queue for Multiple producers and single consumer
spmc
Queue for single producer and multiple consumers

Macros

id_in_queue
Macro of an expression to know if an id is still contain by the queue that have a circular buffer

Enums

QueueError
Error define for Queues Use by utilitary queues an their implementation in ProSA.

Traits

QueueChecker
Trait to define all information getter from the queue