Module config

Module config 

Available on crate feature config only.
Module for ProSA configuration object

Re-exports

pub use url::url_authentication;

Modules

observabilityconfig-observability
Definition of Opentelemetry configuration
ssl
Definition of SSL configuration
tracingconfig-observability
Definition of tracing object use for configuration
url
URL authentication and safe-formatting utilities.

Enums

ConfigError
Error define for configuration object

Functions

hostid
Method to get a consistant host ID (UUID v1 or UUID v4) useful for service.instance.id
hostname
Method to try get the hostname from the OS
os_country
Method to try get the country name from the OS