Module config

Module config 

Available on crate feature config only.
Module for ProSA configuration object

Modules

observabilityconfig-observability
Definition of Opentelemetry configuration
ssl
Definition of SSL configuration
tracingconfig-observability
Definition of tracing object use for configuration

Enums

ConfigError
Error define for configuration object

Functions

hostid
Method to get a consistant host ID (UUID v1 or UUID v4) useful for service.instance.id
hostname
Method to try get the hostname from the OS
os_country
Method to try get the country name from the OS
url_authentication
Method to get authentication value out of URL username/password